@@ -9,7 +9,8 @@ class Config:
     """Configuration of the file parser.
 
     Attributes:
-        excluded_directories: Directory paths not to include in parsing. Can be used to exclude e.g. test directories.
+        excluded_directories: Directory paths not to include in parsing specified via regex. Can be used to exclude
+        e.g. test directories.
     """
 
     excluded_directories: Tuple[str, ...]
